#if defined(__dsPIC30F__)
#include <p30fxxxx.h>
#elif defined(__dsPIC33F__)
#include <p33Fxxxx.h>
#elif defined(__PIC24H__)
#include <p24Hxxxx.h>
#endif

#include "I2C.h"
#include "INT.h"

void I2C_Config(void)
{
	//I2CCON: I2C Control Register
	//bit 15 I2CEN: I2C Enable bit
		//1 = Enables the I2C module and configures the SDA and SCL pins as serial port pins
		//0 = Disables I2C module. All I2C pins are controlled by port functions.
	I2CCONbits.I2CEN=0;
	//bit 14 Unimplemented: Read as 0
	//bit 13 I2CSIDL: Stop in Idle Mode bit
		//1 = Discontinue module operation when device enters an Idle mode
		//0 = Continue module operation in Idle mode
	I2CCONbits.I2CSIDL=0;
	//bit 12 SCLREL: SCL Release Control bit (when operating as I2C Slave)
		//1 = Release SCL clock
		//0 = Hold SCL clock low (clock stretch)
		//If STREN = 1:
			//Bit is R/W (i.e., software may write 0 to initiate stretch and write 1 to release clock)
			//Hardware clear at beginning of slave transmission.
			//Hardware clear at end of slave reception.
		//If STREN = 0:
			//Bit is R/S (i.e., software may only write 1 to release clock)
			//Hardware clear at beginning of slave transmission.
	I2CCONbits.SCLREL=0;
	//bit 11 IPMIEN: Intelligent Peripheral Management Interface (IPMI) Enable bit
		//1 = Enable IPMI Support mode. All addresses Acknowledged.
		//0 = IPMI mode not enabled
	I2CCONbits.IPMIEN=0;
	//bit 10 A10M: 10-bit Slave Address bit
		//1 = I2CADD is a 10-bit slave address
		//0 = I2CADD is a 7-bit slave address
	I2CCONbits.A10M=0;
	//bit 9 DISSLW: Disable Slew Rate Control bit
		//1 = Slew rate control disabled
		//0 = Slew rate control enabled
	I2CCONbits.DISSLW=0;
	//bit 8 SMEN: SMBus Input Levels bit
		//1 = Enable I/O pin thresholds compliant with SMBus specification
		//0 = Disable SMBus input thresholds
	I2CCONbits.SMEN=0;
	//bit 7 GCEN: General Call Enable bit (when operating as I2C slave)
		//1 = Enable interrupt when a general call address is received in the I2CRSR
		//(module is enabled for reception)
		//0 = General call address disabled
	I2CCONbits.GCEN=0;
	//bit 6 STREN: SCL Clock Stretch Enable bit (when operating as I2C slave)
		//Used in conjunction with SCLREL bit.
		//1 = Enable software or receive clock stretching
		//0 = Disable software or receive clock stretching
	I2CCONbits.STREN=0;
	//bit 5 ACKDT: Acknowledge Data bit (When operating as I2C Master. Applicable during master receive.)
		//Value that will be transmitted when the software initiates an Acknowledge sequence.
		//1 = Send NACK during acknowledge
		//0 = Send ACK during acknowledge
	I2CCONbits.ACKDT=0;
	//bit 4 ACKEN: Acknowledge Sequence Enable bit
		//(When operating as I2C master. Applicable during master receive.)
		//1 = Initiate Acknowledge sequence on SDA and SCL pins, and transmit ACKDT data bit
		//Hardware clear at end of master Acknowledge sequence.
		//0 = Acknowledge sequence not in progress
	I2CCONbits.ACKEN=0;
	//bit 3 RCEN: Receive Enable bit (when operating as I2C master)
		//1 = Enables Receive mode for I2C
		//Hardware clear at end eighth bit of master receive data byte.
		//0 = Receive sequence not in progress
	I2CCONbits.RCEN=0;
	//bit 2 PEN: Stop Condition Enable bit (when operating as I2C master)
		//1 = Initiate Stop condition on SDA and SCL pins
		//Hardware clear at end of master Stop sequence.
		//0 = Stop condition not in progress
	I2CCONbits.PEN=0;
	//bit 1 RSEN: Repeated Start Condition Enabled bit (when operating as I2C master)
		//1 = Initiate Repeated Start condition on SDA and SCL pins
		//Hardware clear at end of master Repeated Start sequence.
		//0 = Repeated Start condition not in progress
	I2CCONbits.RSEN=0;
	//bit 0 SEN: Start Condition Enabled bit (when operating as I2C master)
		//1 = Initiate Start condition on SDA and SCL pins
		//Hardware clear at end of master Start sequence.
		//0 = Start condition not in progress
	I2CCONbits.SEN=0;


	//I2CSTAT: I2C Status Register
	//bit 15 ACKSTAT: Acknowledge Status bit
		//(When operating as I2C master. Applicable to master transmit operation.)
		//1 = NACK received from slave
		//0 = ACK received from slave
		//Hardware set or clear at end of slave Acknowledge.
	I2CSTATbits.ACKSTAT=0;
	//bit 14 TRSTAT: Transmit Status bit
		//(When operating as I2C master. Applicable to master transmit operation.)
		//1 = Master transmit is in progress (8 bits + ACK)
		//0 = Master transmit is not in progress
		//Hardware set at beginning of master transmission.
		//Hardware clear at end of slave Acknowledge.
	I2CSTATbits.TRSTAT=0;
	//bit 13-11 Unimplemented: Read as 0
	//bit 10 BCL: Master Bus Collision Detect bit
		//1 = A bus collision has been detected during a master operation
		//0 = No collision
		//Hardware set at detection of bus collision.
	I2CSTATbits.BCL=0;
	//bit 9 GCSTAT: General Call Status bit
		//1 = General call address was received
		//0 = General call address was not received
		//Hardware set when address matches general call address.
		//Hardware clear at Stop detection.
	I2CSTATbits.GCSTAT=0;
	//bit 8 ADD10: 10-bit Address Status bit
		//1 = 10-bit address was matched
		//0 = 10-bit address was not matched
		//Hardware set at match of 2nd byte of matched 10-bit address.
		//Hardware clear at Stop detection.
	I2CSTATbits.ADD10=0;
	//bit 7 IWCOL: Write Collision Detect bit
		//1 = An attempt to write the I2CTRN register failed because the I2C module is busy
		//0 = No collision
		//Hardware set at occurrence of write to I2CTRN while busy (cleared by software).
	I2CSTATbits.IWCOL=0;
	//bit 6 I2COV: Receive Overflow Flag bit
		//1 = A byte was received while the I2CRCV register is still holding the previous byte
		//0 = No overflow
		//Hardware set at attempt to transfer I2CRSR to I2CRCV (cleared by software).
	I2CSTATbits.I2COV=0;
	//bit 5 D_A: Data/Address bit (when operating as I2C slave)
		//1 = Indicates that the last byte received was data
		//0 = Indicates that the last byte received was device address
		//Hardware clear at device address match.
		//Hardware set by write to I2CTRN or by reception of slave byte.
	I2CSTATbits.D_A=0;
	//bit 4 P: Stop bit
		//1 = Indicates that a Stop bit has been detected last
		//0 = Stop bit was not detected last
		//Hardware set or clear when Start, Repeated Start or Stop detected.
	I2CSTATbits.P=0;
	//bit 3 S: Start bit
		//1 = Indicates that a Start (or Repeated Start) bit has been detected last
		//0 = Start bit was not detected last
		//Hardware set or clear when Start, Repeated Start or Stop detected.
	I2CSTATbits.S=0;
	//bit 2 R_W: Read/Write bit Information (when operating as I2C slave)
		//1 = Read - indicates data transfer is output from slave
		//0 = Write - indicates data transfer is input to slave
		//Hardware set or clear after reception of I2C device address byte.
	I2CSTATbits.R_W=0;
	//bit 1 RBF: Receive Buffer Full Status bit
		//1 = Receive complete, I2CRCV is full
		//0 = Receive not complete, I2CRCV is empty
		//Hardware set when I2CRCV written with received byte.
		//Hardware clear when software reads I2CRCV.
	I2CSTATbits.RBF=0;
	//bit 0 TBF: Transmit Buffer Full Status bit
		//1 = Transmit in progress, I2CTRN is full
		//0 = Transmit complete, I2CTRN is empty
		//Hardware set when software writes I2CTRN.
		//Hardware clear at completion of data transmission.
	I2CSTATbits.TBF=0;
}

void _INT_ServiceRoutine _SI2CInterrupt(void)
{
	IFS0bits.SI2CIF=0;
}

void _INT_ServiceRoutine _MI2CInterrupt(void)
{
	IFS0bits.MI2CIF=0;
}
